Re: Some git performance measurements..
- From
Nicolas Pitre <nico@cam.org>
- Date
- Nov 29, 2007, 18:52 UTC
- Message-ID
- <alpine.LFD.0.99999.0711291333460.9605@xanadu.home>
- In-Reply-To
- <alpine.LFD.0.9999.0711290945060.8458@woody.linux-foundation.org>
On Thu, 29 Nov 2007, Linus Torvalds wrote:
Show 20 quoted lines
> > > On Thu, 29 Nov 2007, Nicolas Pitre wrote: > > > > Well, see below for the patch that actually split the pack data into > > objects of the same type. Doing that "git checkout" on the kernel tree > > did improve things for me although not spectacularly. > > Umm. See my earlier numbers. For "git checkout" with cold cache, the > *bulk* of the time is actually the ".gitignore" file lookups, so if you > see a three-second improvement out of 17s, it may not look spectacular, > but considering that probably 10s of those 17s were something *else* going > on, I suspect that if you really did just a plain "git checkout", you > actually *do* have a spectacular improvement of roughly 7s -> 4s! > > Try with > > time git read-tree -m -u HEAD HEAD > /dev/null > > instead.
Oh! OK then.
Current, cold cache: 5.248s Current, warm cache: 0.185s
Patched, cold cache: 3.337s Patched, warm cache: 0.183s
So yes, the improvement is more significant then, although the cold cache timings vary quite a lot between successive tries.
Nicolas